<?php

use App\Models\Settings;
use App\Models\WebSetting;
use Illuminate\Database\Migrations\Migration;
use Illuminate\Database\Schema\Blueprint;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Schema;

return new class extends Migration
{
    /**
     * Run the migrations.
     */
    public function up(): void
    {
        Schema::table('tbl_news', function (Blueprint $table) {
            if (!Schema::hasColumn('tbl_news', 'published_date')) {
                $table->date('published_date')->index('published_date')->after('date');
            }
        });
        DB::table('tbl_news')->update(['published_date' => DB::raw('DATE(date)')]);

        DB::table('tbl_web_settings')->where('type', 'web_color_code')->update(['type' => 'light_primary_color']);
        DB::table('tbl_web_settings')->where('type', 'web_header_logo')->update(['type' => 'light_header_logo']);
        DB::table('tbl_web_settings')->where('type', 'web_footer_logo')->update(['type' => 'light_footer_logo']);
        DB::table('tbl_web_settings')->where('type', 'web_placeholder_image')->update(['type' => 'light_placeholder_image']);
        if (!WebSetting::where('type', 'light_body_color')->exists()) {
            WebSetting::create([
                'type' => 'light_body_color',
                'message' => '#F5F5F5',
            ]);
        }
        if (!WebSetting::where('type', 'light_hover_color')->exists()) {
            WebSetting::create([
                'type' => 'light_hover_color',
                'message' => '#122342',
            ]);
        }
        if (!WebSetting::where('type', 'light_secondary_color')->exists()) {
            WebSetting::create([
                'type' => 'light_secondary_color',
                'message' => '#1A2E51',
            ]);
        }
        if (!WebSetting::where('type', 'light_text_primary_color')->exists()) {
            WebSetting::create([
                'type' => 'light_text_primary_color',
                'message' => '#0F1F40',
            ]);
        }
        if (!WebSetting::where('type', 'light_text_secondary_color')->exists()) {
            WebSetting::create([
                'type' => 'light_text_secondary_color',
                'message' => '#65686D',
            ]);
        }
        if (!WebSetting::where('type', 'dark_body_color')->exists()) {
            WebSetting::create([
                'type' => 'dark_body_color',
                'message' => '#0A1935',
            ]);
        }
        if (!WebSetting::where('type', 'dark_hover_color')->exists()) {
            WebSetting::create([
                'type' => 'dark_hover_color',
                'message' => '#15346D',
            ]);
        }
        if (!WebSetting::where('type', 'dark_primary_color')->exists()) {
            WebSetting::create([
                'type' => 'dark_primary_color',
                'message' => '#CE2B2B',
            ]);
        }
        if (!WebSetting::where('type', 'dark_secondary_color')->exists()) {
            WebSetting::create([
                'type' => 'dark_secondary_color',
                'message' => '#122342',
            ]);
        }
        if (!WebSetting::where('type', 'dark_text_primary_color')->exists()) {
            WebSetting::create([
                'type' => 'dark_text_primary_color',
                'message' => '#ffffff',
            ]);
        }
        if (!WebSetting::where('type', 'dark_text_secondary_color')->exists()) {
            WebSetting::create([
                'type' => 'dark_text_secondary_color',
                'message' => '#98A2B3',
            ]);
        }
        if (!Settings::where('type', 'maintenance_mode')->exists()) {
            Settings::create([
                'type' => 'maintenance_mode',
                'message' => 0,
            ]);
        }
        if (!WebSetting::where('type', 'accept_cookie')->exists()) {
            WebSetting::create([
                'type' => 'accept_cookie',
                'message' => 0,
            ]);
        }
        DB::table('tbl_ad_spaces')->where('ad_space', 'news_details-top')->update(['ad_space' => 'news_details_top']);
        DB::table('tbl_ad_spaces')->where('ad_space', 'news_details-bottom')->update(['ad_space' => 'news_details_bottom']);    
    }

    /**
     * Reverse the migrations.
     */
    public function down(): void
    {
    
    }
};
